@@ -2,21 +2,26 @@
 from contextvars import (
     ContextVar,
 )
+from logging import (
+    Logger,
+)
 from typing import (
     Optional,
     Tuple,
-    TextIO,
 )
 
 # Local libraries
+from tracers.constants import (
+    LOGGER_DEFAULT
+)
 from tracers.containers import (
     Frame,
 )
 
 LEVEL: ContextVar[int] = \
     ContextVar('LEVEL', default=0)
-LOGGING_TO: ContextVar[Optional[TextIO]] = \
-    ContextVar('LOGGING_TO', default=None)
+LOGGER: ContextVar[Optional[Logger]] = \
+    ContextVar('LOGGER', default=LOGGER_DEFAULT)
 STACK: ContextVar[Tuple[Frame, ...]] = \
     ContextVar('STACK', default=())
 TRACING: ContextVar[bool] = \
